<?php

namespace Drupal\socializer\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure Socializer settings for this site.
 */
class SocializerSettingsForm extends ConfigFormBase {

  const SETTINGS = 'socializer.settings';

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'socializer_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      static::SETTINGS,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config(static::SETTINGS);

    $form['links'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Social Media Links'),
    ];

    $form['links']['facebook'] = [
      '#type' => 'url',
      '#title' => $this->t('Facebook'),
      '#description' => t('Specify link to <em>Facebook</em> profile.'),
      '#default_value' => $config->get('links.facebook'),
    ];

    $form['links']['instagram'] = [
      '#type' => 'url',
      '#title' => $this->t('Instagram'),
      '#description' => t('Specify link to <em>Instagram</em> profile.'),
      '#default_value' => $config->get('links.instagram'),
    ];

    $form['links']['twitter'] = [
      '#type' => 'url',
      '#title' => $this->t('Twitter'),
      '#description' => t('Specify link to <em>Twitter</em> profile.'),
      '#default_value' => $config->get('links.twitter'),
    ];

    $form['links']['linkedin'] = [
      '#type' => 'url',
      '#title' => $this->t('LinkedIn'),
      '#description' => t('Specify link to <em>LinkedIn</em> profile.'),
      '#default_value' => $config->get('links.linkedin'),
    ];

    $form['links']['youtube'] = [
      '#type' => 'url',
      '#title' => $this->t('YouTube'),
      '#description' => t('Specify link to <em>YouTube</em> profile.'),
      '#default_value' => $config->get('links.youtube'),
    ];

    $form['links']['pinterest'] = [
      '#type' => 'url',
      '#title' => $this->t('Pinterest'),
      '#description' => t('Specify link to <em>Pinterest</em> profile.'),
      '#default_value' => $config->get('links.pinterest'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config(static::SETTINGS)
      ->set('links.facebook', $form_state->getValue('facebook'))
      ->set('links.instagram', $form_state->getValue('instagram'))
      ->set('links.twitter', $form_state->getValue('twitter'))
      ->set('links.linkedin', $form_state->getValue('linkedin'))
      ->set('links.youtube', $form_state->getValue('youtube'))
      ->set('links.pinterest', $form_state->getValue('pinterest'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
